@@ -35,7 +35,7 @@ class KTp::ContactsFilterModel::Private
 public:
     Private(ContactsFilterModel *parent)
         : q(parent),
-          presenceTypeFilterFlags(DoNotFilterByCapability),
+          presenceTypeFilterFlags(DoNotFilterByPresence),
           capabilityFilterFlags(DoNotFilterByCapability),
           subscriptionStateFilterFlags(DoNotFilterBySubscription),
           globalFilterMatchFlags(Qt::MatchContains),
@@ -67,13 +67,16 @@ public:
     Qt::MatchFlags aliasFilterMatchFlags;
     Qt::MatchFlags groupsFilterMatchFlags;
     Qt::MatchFlags idFilterMatchFlags;
+    Tp::AccountPtr accountFilter;
 
     bool filterAcceptsAccount(const QModelIndex &index) const;
     bool filterAcceptsContact(const QModelIndex &index) const;
     bool filterAcceptsGroup(const QModelIndex &index);
 
     void countContacts(const QModelIndex &sourceParent);
-    void sourceModelChanged(const QModelIndex &sourceIndex);
+
+    void sourceModelParentIndexChanged(const QModelIndex &sourceIndex);
+    void sourceModelIndexChanged(const QModelIndex &sourceIndex);
 
     QHash<QString, int> m_onlineContactsCounts;
     QHash<QString, int> m_totalContactsCounts;
@@ -125,6 +128,11 @@ bool ContactsFilterModel::Private::filterAcceptsContact(const QModelIndex &index
         return false;
     }
 
+    //always return all subcontacts of a metacontact
+    if (index.parent().isValid() && index.parent().data(KTp::RowTypeRole).toUInt() == KTp::PersonRowType) {
+        return true;
+    }
+
     // Check presence type
     if (presenceTypeFilterFlags != DoNotFilterByPresence) {
         switch (static_cast<Tp::ConnectionPresenceType>(index.data(KTp::ContactPresenceTypeRole).toUInt())) {
@@ -316,6 +324,13 @@ bool ContactsFilterModel::Private::filterAcceptsContact(const QModelIndex &index
         }
     }
 
+    //check account
+    if (accountFilter) {
+        if(index.data(KTp::AccountRole).value<Tp::AccountPtr>() != accountFilter) {
+            return false;
+        }
+    }
+
     return true;
 }
 
@@ -388,19 +403,18 @@ void ContactsFilterModel::Private::countContacts(const QModelIndex &sourceParent
     m_totalContactsCounts.insert(key, tmpCounter);
 }
 
-void ContactsFilterModel::Private::sourceModelChanged(const QModelIndex &sourceIndex)
+void ContactsFilterModel::Private::sourceModelParentIndexChanged(const QModelIndex &sourceIndex)
 {
-    QModelIndex groupSourceIndex;
-    if (sourceIndex.data(KTp::RowTypeRole).toUInt() == KTp::ContactRowType) {
-        groupSourceIndex = sourceIndex.parent();
-    } else {
-        groupSourceIndex = sourceIndex;
+    if (sourceIndex.isValid()) {
+        countContacts(sourceIndex);
+        const QModelIndex mappedIndex = q->mapFromSource(sourceIndex);
+        Q_EMIT q->dataChanged(mappedIndex, mappedIndex);
     }
+}
 
-    countContacts(groupSourceIndex);
-
-    const QModelIndex mappedIndex = q->mapFromSource(sourceIndex);
-    Q_EMIT q->dataChanged(mappedIndex, mappedIndex);
+void ContactsFilterModel::Private::sourceModelIndexChanged(const QModelIndex &sourceIndex)
+{
+    sourceModelParentIndexChanged(sourceIndex.parent());
 }
 
 
@@ -451,29 +465,32 @@ void ContactsFilterModel::setSourceModel(QAbstractItemModel *sourceModel)
     // Disconnect the previous source model
     if (this->sourceModel()) {
         disconnect(this->sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                this, SLOT(sourceModelChanged(QModelIndex)));
+                this, SLOT(sourceModelIndexChanged(QModelIndex)));
         disconnect(this->sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                this, SLOT(sourceModelChanged(QModelIndex)));
+                this, SLOT(sourceModelParentIndexChanged(QModelIndex)));
         disconnect(this->sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                this, SLOT(sourceModelChanged(QModelIndex)));
+                this, SLOT(sourceModelParentIndexChanged(QModelIndex)));
         disconnect(this->sourceModel(), SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
-                this, SLOT(sourceModelChanged(QModelIndex)));
+                this, SLOT(sourceModelParentIndexChanged(QModelIndex)));
     }
 
     // Clear all cached values as they aren't valid anymore because the source model changed.
     d->m_onlineContactsCounts.clear();
     d->m_totalContactsCounts.clear();
-    QSortFilterProxyModel::setSourceModel(sourceModel);
 
-    // Connect the new source model
-    connect(this->sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            this, SLOT(sourceModelChanged(QModelIndex)));
-    connect(this->sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-            this, SLOT(sourceModelChanged(QModelIndex)));
-    connect(this->sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-            this, SLOT(sourceModelChanged(QModelIndex)));
-    connect(this->sourceModel(), SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
-            this, SLOT(sourceModelChanged(QModelIndex)));
+    if (sourceModel) {
+        QSortFilterProxyModel::setSourceModel(sourceModel);
+
+        // Connect the new source model
+        connect(this->sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
+                this, SLOT(sourceModelIndexChanged(QModelIndex)));
+        connect(this->sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
+                this, SLOT(sourceModelParentIndexChanged(QModelIndex)));
+        connect(this->sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+                this, SLOT(sourceModelParentIndexChanged(QModelIndex)));
+        connect(this->sourceModel(), SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
+                this, SLOT(sourceModelParentIndexChanged(QModelIndex)));
+    }
 }
 
 void ContactsFilterModel::invalidateFilter()
@@ -755,6 +772,26 @@ Qt::MatchFlags ContactsFilterModel::idFilterMatchFlags() const
     return d->idFilterMatchFlags;
 }
 
+
+Tp::AccountPtr ContactsFilterModel::accountFilter() const
+{
+    return d->accountFilter;
+}
+
+void ContactsFilterModel::setAccountFilter(const Tp::AccountPtr &accountFilter)
+{
+    if (d->accountFilter != accountFilter) {
+        d->accountFilter = accountFilter;
+        invalidateFilter();
+        Q_EMIT accountFilterChanged(accountFilter);
+    }
+}
+
+void ContactsFilterModel::clearAccountFilter()
+{
+    setAccountFilter(Tp::AccountPtr());
+}
+
 void ContactsFilterModel::resetIdFilterMatchFlags()
 {
     setIdFilterMatchFlags(Qt::MatchStartsWith | Qt::MatchWrap);
@@ -793,7 +830,7 @@ bool ContactsFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex &sou
     QModelIndex index = sourceModel()->index(sourceRow, 0, sourceParent);
 
     int type = index.data(KTp::RowTypeRole).toInt();
-    if (type == KTp::ContactRowType) {
+    if (type == KTp::ContactRowType || type == KTp::PersonRowType) {
         return d->filterAcceptsContact(index);
     }
     else if (type == KTp::AccountRowType) {
