@@ -30,12 +30,13 @@
 #include <TelepathyQt/AccountManager>
 #include <TelepathyQt/AccountFactory>
 #include <TelepathyQt/PendingReady>
+#include <TelepathyQt/PendingChannelRequest>
 
 #include <KTp/debug.h>
-#include <KTp/Models/accounts-model.h>
-#include <KTp/Models/accounts-filter-model.h>
+#include <KTp/Models/contacts-list-model.h>
+#include <KTp/Models/contacts-filter-model.h>
 #include <KTp/Widgets/contact-grid-widget.h>
-#include <telepathy-qt4/TelepathyQt/PendingChannelRequest>
+#include <KTp/contact-factory.h>
 
 
 
@@ -44,7 +45,7 @@ class KTp::ContactGridDialog::Private
 public:
     Private(KTp::ContactGridDialog *parent) :
         q(parent),
-        accountsModel(0),
+        contactsModel(0),
         account(0),
         contact(0)
     {
@@ -53,7 +54,7 @@ public:
     KTp::ContactGridDialog * const q;
 
     Tp::AccountManagerPtr accountManager;
-    AccountsModel *accountsModel;
+    KTp::ContactsListModel *contactsModel;
     KTp::ContactGridWidget *contactGridWidget;
     Tp::AccountPtr account;
     Tp::ContactPtr contact;
@@ -68,7 +69,7 @@ public Q_SLOTS:
 void KTp::ContactGridDialog::Private::_k_onAccountManagerReady()
 {
     kDebug() << "Account manager is ready";
-    accountsModel->setAccountManager(accountManager);
+    contactsModel->setAccountManager(accountManager);
 }
 
 void KTp::ContactGridDialog::Private::_k_onOkClicked()
@@ -118,7 +119,7 @@ KTp::ContactGridDialog::ContactGridDialog(QWidget *parent) :
                                                                                               << Tp::Connection::FeatureRoster
                                                                                               << Tp::Connection::FeatureSelfContact);
 
-    Tp::ContactFactoryPtr contactFactory = Tp::ContactFactory::create(Tp::Features()  << Tp::Contact::FeatureAlias
+    Tp::ContactFactoryPtr contactFactory = KTp::ContactFactory::create(Tp::Features()  << Tp::Contact::FeatureAlias
                                                                                       << Tp::Contact::FeatureAvatarData
                                                                                       << Tp::Contact::FeatureSimplePresence
                                                                                       << Tp::Contact::FeatureCapabilities);
@@ -131,13 +132,13 @@ KTp::ContactGridDialog::ContactGridDialog(QWidget *parent) :
                                                    channelFactory,
                                                    contactFactory);
 
-    d->accountsModel = new AccountsModel(this);
+    d->contactsModel = new KTp::ContactsListModel(this);
     connect(d->accountManager->becomeReady(), SIGNAL(finished(Tp::PendingOperation*)), SLOT(_k_onAccountManagerReady()));
 
 
-    d->contactGridWidget = new KTp::ContactGridWidget(d->accountsModel, this);
+    d->contactGridWidget = new KTp::ContactGridWidget(d->contactsModel, this);
     d->contactGridWidget->contactFilterLineEdit()->setClickMessage(i18n("Search in Contacts..."));
-    d->contactGridWidget->filter()->setPresenceTypeFilterFlags(AccountsFilterModel::ShowOnlyConnected);
+    d->contactGridWidget->filter()->setPresenceTypeFilterFlags(KTp::ContactsFilterModel::ShowOnlyConnected);
 
     setMainWidget(d->contactGridWidget);
 
@@ -166,7 +167,7 @@ Tp::ContactPtr KTp::ContactGridDialog::contact()
     return d->contact;
 }
 
-AccountsFilterModel* KTp::ContactGridDialog::filter() const
+KTp::ContactsFilterModel* KTp::ContactGridDialog::filter() const
 {
     return d->contactGridWidget->filter();
 }
